@@ -56,7 +56,6 @@ struct
     | `Url_width of uri * Html_types.number
     | `Url_pixel of uri * Html_types.float_number ]
 
-
   type 'a attrib = Xml.attrib
 
   let to_xmlattribs x = x
@@ -118,6 +117,7 @@ struct
   let a_oncanplay = Xml.event_handler_attrib "oncanplay"
   let a_oncanplaythrough = Xml.event_handler_attrib "oncanplaythrough"
   let a_onchange = Xml.event_handler_attrib "onchange"
+  let a_onclose = Xml.event_handler_attrib "onclose"
   let a_ondurationchange = Xml.event_handler_attrib "ondurationchange"
   let a_onemptied = Xml.event_handler_attrib "onemptied"
   let a_onended = Xml.event_handler_attrib "onended"
@@ -255,7 +255,7 @@ struct
   let a_method x =
     user_attrib C.string_of_big_variant "method" x
 
-  let a_formmethod = a_method
+  let a_formmethod x = user_attrib C.string_of_big_variant "formmethod" x
 
   let a_enctype = string_attrib "enctype"
 
@@ -284,7 +284,7 @@ struct
     user_attrib C.string_of_referrerpolicy "referrerpolicy" x
 
   let a_autocomplete x =
-    user_attrib C.onoff_of_bool "autocomplete" x
+    user_attrib C.string_of_autocomplete "autocomplete" x
 
   let a_async =
     constant_attrib "async"
@@ -439,6 +439,8 @@ struct
   let a_button_type bt =
     user_attrib C.string_of_input_type "type" bt
 
+  let a_script_type sc = user_attrib C.string_of_script_type "type" sc
+
   let a_multiple =
     constant_attrib "multiple"
 
@@ -571,6 +573,8 @@ struct
 
   let blockquote = star "blockquote"
 
+  let dialog = star "dialog"
+
   let div = star "div"
 
   let p = star "p"
@@ -807,7 +811,8 @@ struct
     Xml.leaf ~a "img"
 
   let picture ~img ?a elts =
-    let content = W.cons img elts in
+    let tail_node = W.cons img (W.nil ()) in
+    let content = W.append elts tail_node in
     Xml.node ?a "picture" content
 
   let meta = terminal "meta"
@@ -881,6 +886,7 @@ struct
     | `Author -> "author"
     | `Bookmark -> "bookmark"
     | `Canonical -> "canonical"
+    | `Dns_prefetch -> "dns-prefetch"
     | `External -> "external"
     | `First -> "first"
     | `Help -> "help"
@@ -888,12 +894,19 @@ struct
     | `Index -> "index"
     | `Last -> "last"
     | `License -> "license"
+    | `Manifest -> "manifest"
+    | `Me -> "me"
+    | `Modulepreload -> "modulepreload"
     | `Next -> "next"
     | `Nofollow -> "nofollow"
-    | `Noreferrer -> "noreferrer"
     | `Noopener -> "noopener"
+    | `Noreferrer -> "noreferrer"
+    | `Opener -> "opener"
     | `Pingback -> "pingback"
+    | `Preconnect -> "preconnect"
     | `Prefetch -> "prefetch"
+    | `Preload -> "preload"
+    | `Prerender -> "prerender"
     | `Prev -> "prev"
     | `Search -> "search"
     | `Stylesheet -> "stylesheet"
@@ -1054,6 +1067,11 @@ struct
     | `Url -> "url"
     | `Week -> "week"
 
+  let string_of_script_type = function
+  | `Javascript -> "application/javascript"
+  | `Module -> "module"
+  | `Mime s -> s
+
   let string_of_number_or_datetime = function
     | `Number n -> string_of_int n
     | `Datetime t -> t
@@ -1110,6 +1128,12 @@ struct
     in
     String.concat ", " (List.map f l)
 
+  let string_of_autocomplete (l : Html_types.autocomplete_option) =
+    match l with
+    | `On | `Tokens [] -> "on"
+    | `Off -> "off"
+    | `Tokens strs -> String.concat " " strs
+
 end
 
 module Make
