@@ -108,6 +108,7 @@ type linktype =
     | `Author
     | `Bookmark
     | `Canonical
+    | `Dns_prefetch
     | `External
     | `First
     | `Help
@@ -115,13 +116,20 @@ type linktype =
     | `Index
     | `Last
     | `License
+    | `Manifest
+    | `Me
+    | `Modulepreload
     | `Next
     | `Nofollow
-    | `Noreferrer
     | `Noopener
+    | `Noreferrer
+    | `Opener
     | `Pingback
+    | `Preconnect
     | `Prefetch
     | `Prev
+    | `Preload
+    | `Prerender
     | `Search
     | `Stylesheet
     | `Sidebar
@@ -151,6 +159,8 @@ type linktypes = linktype list
         Gives the permalink for the nearest ancestor section.}
         {- [`Canonical]:
         Gives the preferred location for accessing the current document.}
+        {- [`Dns_prefetch]:
+        Specifies that the user agent should preemptively perform DNS resolution for the target resource's origin..}
         {- [`External]:
         Indicates that the referenced document is not part of the same site as the current document.}
         {- [`First]:
@@ -165,18 +175,32 @@ type linktypes = linktype list
         Indicates that the current document is a part of a series, and that the last document in the series is the referenced document.}
         {- [`Licence]:
         Indicates that the main content of the current document is covered by the copyright license described by the referenced document.}
+        {- [`Manifest]:
+        Imports or links to an application manifest.}
+        {- [`Me]:
+        Indicates that the current document represents the person who owns the linked content.}
+        {- [`Modulepreload]:
+        Specifies that the user agent must preemptively fetch the module script and store it in the document's module map for later evaluation. Optionally, the module's dependencies can be fetched as well.}
         {- [`Next]:
         Indicates that the current document is a part of a series, and that the next document in the series is the referenced document.}
         {- [`Nofollow]:
         Indicates that the current document's original author or publisher does not endorse the referenced document.}
-        {- [`Noreferrer]:
-        Requires that the user agent not send an HTTP Referer (sic) header if the user follows the hyperlink.}
         {- [`Noopener]:
         Instructs the browser to open the link without granting the new browsing context access to the document that opened it.}
+        {- [`Noreferrer]:
+        Requires that the user agent not send an HTTP Referer (sic) header if the user follows the hyperlink.}
+        {- [`Opener]:
+        Creates an auxiliary browsing context if the hyperlink would otherwise create a top-level traversable with a non-auxiliary browsing context (i.e., has "_blank" as target attribute value).}
         {- [`Pingback]:
         Gives the address of the pingback server that handles pingbacks to the current document.}
+        {- [`Preconnect]:
+        Specifies that the user agent should preemptively connect to the target resource's origin.}
         {- [`Prefetch]:
         Specifies that the target resource should be preemptively cached.}
+        {- [`Preload]:
+        Specifies that the user agent must preemptively fetch and cache the target resource for current navigation according to the potential destination given by the as attribute (and the priority associated with the corresponding destination).}
+        {- [`Prerender]:
+        Specifies that the user agent should preemptively fetch the target resource and process it in a way that helps deliver a faster response in the future.}
         {- [`Prev]:
         Indicates that the current document is a part of a series, and that the previous document in the series is the referenced document.}
         {- [`Search]:
@@ -276,6 +300,7 @@ type core =
     | `Spellcheck
     | `Style_Attr
     | `Tabindex
+    | `Translate
     | `Title
     | `User_data
     | `XMLns
@@ -292,6 +317,7 @@ type events =
     | `OnCanPlayThrough
     | `OnChange
     | `OnClick
+    | `OnClose
     | `OnContextMenu
     | `OnDblClick
     | `OnDrag
@@ -391,7 +417,7 @@ type formatblock =
   ]
 
 type sectionningroot =
-  [ | `Td | `Figure | `Fieldset | `Details | `Body | `Blockquote
+  [ | `Td | `Figure | `Fieldset | `Details | `Body | `Blockquote | `Dialog
   ]
 
 type listed = [ | resetable | submitable | `Fieldset ]
@@ -543,6 +569,7 @@ type core_phrasing =
     | `B
     | `Abbr
     | `Img | `Img_interactive
+    | `Picture
     | `PCDATA
   ]
 
@@ -580,6 +607,7 @@ type core_phrasing_without_noscript =
     | `Br
     | `Bdo
     | `Img | `Img_interactive
+    | `Picture
     | `B
     | `Abbr
     | `PCDATA
@@ -590,7 +618,6 @@ type core_phrasing_without_interactive =
     | `Wbr
     | `Var
     | `U
-    | `Img
     | `Time
     | `Template
     | `Sup
@@ -606,6 +633,7 @@ type core_phrasing_without_interactive =
     | `Mark
     | `Kbd
     | `Img
+    | `Picture
     | `I
     | `Em
     | `Dfn
@@ -643,6 +671,7 @@ type core_phrasing_without_media =
     | `Label
     | `Kbd
     | `Img | `Img_interactive
+    | `Picture
     | `Iframe
     | `I
     | `Embed
@@ -693,7 +722,7 @@ type (+'a, +'b) between_phrasing_and_phrasing_without_interactive =
                                            phrasing,
                                            phrasing_without_media) transparent
         > `Abbr `B `Bdo `Br `Canvas `Cite `Code `Command
-        `Datalist `Del `Dfn `Em `I `Img `Ins `Kbd `Map `Mark `Meter
+        `Datalist `Del `Dfn `Em `I `Img `Picture `Ins `Kbd `Map `Mark `Meter
         `Noscript `Object `PCDATA `Progress `Q `Ruby `Samp `Script
         `Small `Span `Strong `Sub `Sup `Svg `Template `Time `U `Var `Wbr ] as 'a)
 
@@ -719,6 +748,7 @@ type phrasing_without_dfn =
     | `Mark
     | `Label
     | `Img | `Img_interactive
+    | `Picture
     | `Kbd
     | `I
     | `Em
@@ -749,6 +779,7 @@ type phrasing_without_label =
     | `Strong
     | `Span
     | `Img | `Img_interactive
+    | `Picture
     | `Small
     | `Script
     | `Samp
@@ -789,6 +820,7 @@ type phrasing_without_progress =
     | `Script
     | `Samp
     | `Img | `Img_interactive
+    | `Picture
     | `Ruby
     | `Q
     | `Meter
@@ -824,6 +856,7 @@ type phrasing_without_time =
     | `Sub
     | `Strong
     | `Img | `Img_interactive
+    | `Picture
     | `Span
     | `Small
     | `Script
@@ -862,6 +895,7 @@ type phrasing_without_meter =
     | `Template
     | `Sup
     | `Img | `Img_interactive
+    | `Picture
     | `Sub
     | `Strong
     | `Span
@@ -905,6 +939,7 @@ type core_flow5 =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
   ]
 
 type core_flow5_without_interactive =
@@ -922,6 +957,7 @@ type core_flow5_without_interactive =
     | `Figure
     | `Dl
     | `Main
+    | `Dialog
   ]
 
 type core_flow5_without_noscript =
@@ -940,6 +976,7 @@ type core_flow5_without_noscript =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
   ]
 type core_flow5_without_media =
   [
@@ -957,6 +994,7 @@ type core_flow5_without_media =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
   ]
 
 type flow5_without_interactive =
@@ -1000,6 +1038,7 @@ type flow5_without_table =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
     | (flow5_without_interactive, flow5_without_noscript, flow5,
        flow5_without_media) transparent
   ]
@@ -1025,6 +1064,7 @@ type flow5_without_interactive_header_footer =
     | `Figure
     | `Dl
     | `Main
+    | `Dialog
     | (flow5_without_noscript, flow5, flow5_without_media)
         transparent_without_interactive
   ]
@@ -1051,6 +1091,7 @@ type flow5_without_header_footer =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
     | (flow5_without_interactive_header_footer,
        flow5_without_noscript, flow5,
        flow5_without_media) transparent
@@ -1058,8 +1099,8 @@ type flow5_without_header_footer =
 
 type +'a between_flow5_and_flow5_without_interactive_header_footer =
   [< flow5  > `Abbr `Address `Article `Aside `Audio `B `Bdo `Blockquote `Br
-       `Button `Canvas `Cite `Code `Command `Datalist `Del `Dfn `Div `Dl `Em
-       `Fieldset `Figure `Form `H1 `H2 `H3 `H4 `H5 `H6 `Hgroup `Hr `I `Img
+       `Button `Canvas `Cite `Code `Command `Datalist `Del `Dfn `Dialog `Div `Dl `Em
+       `Fieldset `Figure `Form `H1 `H2 `H3 `H4 `H5 `H6 `Hgroup `Hr `I `Img `Picture
        `Input `Ins `Kbd `Keygen `Label `Map`Mark `Menu `Meter `Nav `Noscript
        `Object `Ol `Output `P `PCDATA `Pre `Progress `Q `Ruby `Samp `Script
        `Section `Select `Small `Span `Strong `Style `Sub `Sup `Svg `Table
@@ -1073,9 +1114,9 @@ type (+'a, +'b) between_flow5_and_flow5_without_header_footer =
       transparent
       > `A `Abbr `Address `Article `Aside `Audio `Audio_interactive `B
       `Bdo `Blockquote `Br `Button `Canvas `Cite `Code `Command
-      `Datalist `Del `Details `Dfn `Div `Dl `Em `Embed `Fieldset
+      `Datalist `Del `Details `Dfn `Dialog `Div `Dl `Em `Embed `Fieldset
       `Figure `Form `H1 `H2 `H3 `H4 `H5 `H6 `Hgroup `Hr `I `Iframe
-      `Img `Img_interactive `Input `Ins `Kbd `Keygen `Label `Map
+      `Img `Img_interactive `Picture `Input `Ins `Kbd `Keygen `Label `Map
       `Mark `Menu `Meter `Nav `Noscript `Object `Object_interactive
       `Ol `Output `P `PCDATA `Pre `Progress `Q `Ruby `Samp `Script
       `Section `Select `Small `Span `Strong `Style `Sub `Sup `Svg
@@ -1097,6 +1138,7 @@ type flow5_without_form =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
     | (flow5_without_interactive, flow5_without_noscript, flow5,
        flow5_without_media) transparent
   ]
@@ -1120,6 +1162,7 @@ type flow5_without_sectioning_heading_header_footer_address =
     | `Dl
     | `Details
     | `Main
+    | `Dialog
     | (flow5_without_interactive, flow5_without_noscript, flow5,
        flow5_without_media) transparent
   ]
@@ -1371,6 +1414,15 @@ type blockquote_content_fun = [ | flow5 ]
 
 type blockquote_attrib = [ | common | `Cite ]
 
+(* NAME: dialog, KIND: star, TYPE: [= common | `Open ], [= flow5 ], [=`Dialog], ARG: [= flow5 ], ATTRIB:  OUT: [=`Dialog] *)
+type dialog = [ | `Dialog ]
+
+type dialog_content = [ | flow5 ]
+
+type dialog_content_fun = [ | flow5 ]
+
+type dialog_attrib = [ | common | `Open ]
+
 (* NAME: div, KIND: star, TYPE: [= common ], [= flow5 ], [=`Div], ARG: [= flow5 ], ATTRIB:  OUT: [=`Div] *)
 type div = [ | `Div ]
 
@@ -1826,7 +1878,7 @@ type source_content = notag
 
 type source_content_fun = notag
 
-type source_attrib = [ | common | `Src | `Mime_type | `Media ]
+type source_attrib = [ | common | `Src | `Srcset | `Mime_type | `Media ]
 
 (* NAME: area, KIND: nullary, TYPE: [= common | `Alt | `Coords | `Shape| `Target | `Rel | `Media| `Hreflang | `Mime_type],[=`Area], ARG: notag, ATTRIB:  OUT: [=`Area] *)
 type area = [ | `Area ]
@@ -2022,8 +2074,9 @@ type input_attrib =
     | `Checked
     | `Disabled
     | `Form
-    | `Formation
+    | `Formaction
     | `Formenctype
+    | `Formmethod
     | `Method
     | `Formnovalidate
     | `Formtarget
@@ -2086,6 +2139,7 @@ type button_attrib =
     | `Form
     | `Formaction
     | `Formenctype
+    | `Formmethod
     | `Method
     | `Formnovalidate
     | `Formtarget
@@ -2241,7 +2295,7 @@ type script = [ | `Script ]
 
 type script_attrib =
   [ | common | subressource_integrity
-    | `Async | `Charset | `Src | `Defer | `Mime_type
+    | `Async | `Charset | `Src | `Defer | `Script_type
   ]
 
 type script_content = [ | `PCDATA ]
@@ -2269,6 +2323,11 @@ type link_attrib =
     | `Hreflang | `Media | `Rel | `Href | `Sizes | `Mime_type
   ]
 
+type picture = [ | `Picture ]
+type picture_content = [ | source | script | template ]
+type picture_content_fun = [ | source | script | template ]
+type picture_attrib = [ | common ]
+
 type referrerpolicy = [
   | `Empty
   | `No_referrer
@@ -2356,6 +2415,9 @@ type big_variant =
   | `Tel
   | `Email
   | `Url
+  | `Text
+  | `Decimal
+  | `Search
   ]
 
 type sandbox_token =
@@ -2391,3 +2453,7 @@ type input_type =
   | `Time
   | `Url
   | `Week ]
+
+type script_type = [ `Javascript | `Module | `Mime of string ]
+
+type autocomplete_option = [ `On | `Off | `Tokens of string list]
