@@ -101,6 +101,10 @@ let string_of_paint = function
     (string_of_iri iri) ^" "^ (string_of_paint_whitout_icc b)
   | #paint_whitout_icc as c -> string_of_paint_whitout_icc c
 
+let string_of_fill_rule = function
+  | `Nonzero -> "nonzero"
+  | `Evenodd -> "evenodd"
+
 module Make_with_wrapped_functions
 
     (Xml : Xml_sigs.T)
@@ -535,6 +539,8 @@ struct
   let a_animation_fill x =
     user_attrib C.string_of_big_variant "fill" x
 
+  let a_fill_rule = user_attrib C.string_of_fill_rule "fill-rule"
+
   let a_calcMode x =
     user_attrib C.string_of_big_variant "calcMode" x
 
@@ -862,7 +868,9 @@ struct
 
   let script = unary "script"
 
-  let animation = star "animate"
+  let animate = star "animate"
+
+  let animation = animate
 
   let set = star "set"
 
@@ -1106,6 +1114,8 @@ struct
 
   let string_of_paint = string_of_paint
 
+  let string_of_fill_rule = string_of_fill_rule
+
   let string_of_strokedasharray = function
     | [] -> "none"
     | l -> list string_of_length l
