@@ -275,7 +275,7 @@ module type T = sig
     [< `UserSpaceOnUse | `ObjectBoundingBox ] wrap ->
     [ | `GradientUnits ] attrib
 
-  val a_gradientTransform : transforms wrap -> [> | `Gradient_Transform ] attrib
+  val a_gradientTransform : transforms wrap -> [> | `GradientTransform ] attrib
 
   val a_spreadMethod :
     [< `Pad | `Reflect | `Repeat ] wrap -> [> | `SpreadMethod ] attrib
@@ -486,13 +486,15 @@ module type T = sig
   val a_fill : paint wrap -> [> | `Fill ] attrib
 
   val a_animation_fill : [< | `Freeze | `Remove ] wrap -> [> | `Fill_Animation ] attrib
-    [@@reflect.attribute "fill" ["animation"]]
+    [@@reflect.attribute "fill" ["animate"]]
+
+  val a_fill_rule : fill_rule wrap -> [> | `Fill_rule ] attrib
 
   val a_calcMode :
     [< | `Discrete | `Linear | `Paced | `Spline ] wrap -> [> | `CalcMode ] attrib
 
   val a_animation_values : strings wrap -> [> | `Valuesanim ] attrib
-    [@@reflect.attribute "values" ["animation"]]
+    [@@reflect.attribute "values" ["animate"]]
 
   val a_keyTimes : strings wrap -> [> | `KeyTimes ] attrib
 
@@ -884,8 +886,8 @@ module type T = sig
   val script :
     ([< | script_attr], [< | script_content], [> | script]) unary
 
-  val animation :
-    ([< | animation_attr], [< | animation_content], [> | animation]) star
+  val animate :
+    ([< | animate_attr], [< | animate_content], [> | animate]) star
 
   val set : ([< | set_attr], [< | set_content], [> | set]) star
 
@@ -963,7 +965,12 @@ module type T = sig
   [@@ocaml.deprecated "Use txt instead"]
   (** @deprecated Use txt instead *)
 
-  (** {2 Conversion with untyped representation} 
+  val animation :
+    ([< | animate_attr], [< | animate_content], [> | animate]) star
+  [@@ocaml.deprecated "Use animate instead"]
+  (** @deprecated Use animate instead *)
+
+  (** {2 Conversion with untyped representation}
 
       WARNING: These functions do not ensure HTML or SVG validity! You should
       always explicitly given an appropriate type to the output.
@@ -1105,6 +1112,8 @@ module type Wrapped_functions = sig
   val string_of_orient : (Svg_types.Unit.angle option, string) Xml.W.ft
 
   val string_of_paint : ([< Svg_types.paint], string) Xml.W.ft
+  
+  val string_of_fill_rule : ([< Svg_types.fill_rule], string) Xml.W.ft
 
   val string_of_strokedasharray : (Svg_types.lengths, string) Xml.W.ft
 
