@@ -484,6 +484,17 @@ let paint ?separated_by:_ ?default:_ loc name s =
             `Icc ([%e iri], Some [%e paint_without_icc loc name remainder])]
     end [@metaloc loc]
 
+let fill_rule ?separated_by:_ ?default:_ loc _name s =
+  begin match s with
+  | "nonzero" ->
+    Some [%expr `Nonzero]
+  
+  | "evenodd" ->
+    Some [%expr `Evenodd]
+
+  | _ -> None
+  end [@metaloc loc]
+
 let srcset_element =
   let space = Re_str.regexp " +" in
 
@@ -540,8 +551,31 @@ let number_or_datetime ?separated_by:_ ?default:_ loc _ s =
   | None -> Some [%expr `Datetime [%e Common.string loc s]]
   [@metaloc loc]
 
+let autocomplete ?separated_by:_ ?default:_ loc name s =
+  match s with
+  | "on" | "" -> Some [%expr `On]
+  | "off" -> Some [%expr `Off]
+  | tks ->
+    match spaces (string) loc name tks with
+      | Some tks -> Some [%expr `Tokens [%e tks]]
+      | None -> Common.error loc "Bad autocomplete tokens"
+  [@metaloc loc]
 
 
+let script_type =
+  (* According to https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script, non-javascript
+     MIME types are allowed, but then denotes the <script> content as a "data block" (whatever that
+     is), implying that any `src` attribute be ignored. As a first approximation, let's just make
+     sure that any non-"module" type attribute is a plausible mime type.  *)
+  let maybeMime = Re.Str.regexp ".+/.+" in
+  fun ?separated_by:_ ?default:_ loc _ s ->
+    if s = "module"
+    then Some [%expr `Module]
+    else if Re.Str.string_match maybeMime s 0
+         then Some [%expr `Mime [%e Common.string loc s]]
+         else Common.error loc {|script type attribute must be "module" or a mime type|}
+    [@metaloc loc]
+
 (* Special-cased. *)
 
 let sandbox = spaces variant
