@@ -147,10 +147,10 @@ let basics = "ppx basics", HtmlTests.make Html.[
 
   "datalist",
   [[%html {|<datalist>
-	<option value="foo">foo</option>
+        <option value="foo">foo</option>
 </datalist>|}]],
   [datalist ~children:(`Options [option ~a:[a_value "foo"] (txt "foo")]) ()];
-  
+
   "comments",
   [[%html {|<div><p>a</p><!-- b --><hr/></div>|}]],
   [div [p [txt "a"]; tot (Xml.comment " b "); hr ()]] ;
@@ -168,7 +168,7 @@ let basics = "ppx basics", HtmlTests.make Html.[
   "type in source",
   [[%html {|<source src="foo.mp3" type="audio/mpeg"/>|}]],
   [source ~a:[a_src "foo.mp3"; a_mime_type "audio/mpeg"] ()];
-    
+
   "table with body",
   [[%html "<table><tbody></tbody></table>"]],
   [tablex [tbody []]];
@@ -185,6 +185,10 @@ let basics = "ppx basics", HtmlTests.make Html.[
   [[%html "<table><tbody>"[tr []]"</tbody></table>"]],
   [tablex [tbody [tr[]]]];
 
+  "dialog",
+  [[%html {|<dialog open>foo</dialog>|}]],
+  [dialog ~a:[a_open ()] [txt "foo"] ];
+
   "picture",
   [[%html {|<div><picture id="idpicture">
     <img src="picture/img.png" alt="test picture/img.png" id="idimg"/>
@@ -199,6 +203,22 @@ let basics = "ppx basics", HtmlTests.make Html.[
     ]
   ]];
 
+  "script type=module",
+  [[%html {|<script type="module"></script>|}]],
+  [script ~a:[a_script_type `Module] @@ txt ""];
+
+  "script type=mime",
+  [[%html {|<script type="text/javascript"></script>|}]],
+  [script ~a:[a_script_type (`Mime "text/javascript")] @@ txt ""];
+
+  "script empty",
+  [[%html {|<script></script>|}]],
+  [script @@ txt ""];
+
+  "textarea empty",
+  [[%html {|<textarea></textarea>|}]],
+  [textarea @@ txt ""];
+
 ]
 
 let attribs = "ppx attribs", HtmlTests.make Html.[
@@ -223,17 +243,45 @@ let attribs = "ppx attribs", HtmlTests.make Html.[
   [[%html "<div draggable=false></div>"]],
   [div ~a:[a_draggable false] []] ;
 
-  "onoff default",
+  "form autocomplete default is on",
   [[%html "<form autocomplete></form>"]],
-  [form ~a:[a_autocomplete true] []] ;
+  [form ~a:[a_autocomplete `On] []] ;
 
-  "bool true",
+  "form autocomplete on",
   [[%html "<form autocomplete=on></form>"]],
-  [form ~a:[a_autocomplete true] []] ;
+  [form ~a:[a_autocomplete `On] []] ;
 
-  "bool false",
+  "form autocomplete off",
   [[%html "<form autocomplete=off></form>"]],
-  [form ~a:[a_autocomplete false] []] ;
+  [form ~a:[a_autocomplete `Off] []] ;
+
+  "form autocomplete tokenlist",
+  [[%html "<form autocomplete='section-blue shipping street-address'></form>"]],
+  [form ~a:[a_autocomplete (`Tokens ["section-blue"; "shipping"; "street-address"] )] []] ;
+
+  "form autocomplete tokenlist empty",
+  [[%html "<form autocomplete=on></form>"]],
+  [form ~a:[a_autocomplete (`Tokens [] )] []] ;
+
+  "input autocomplete default is on",
+  [[%html "<input autocomplete/>"]],
+  [input ~a:[a_autocomplete `On] ()] ;
+  
+  "input autocomplete on",
+  [[%html "<input autocomplete='on'/>"]],
+  [input ~a:[a_autocomplete `On] ()] ;
+  
+  "input autocomplete off",
+  [[%html "<input autocomplete='off'/>"]],
+  [input~a:[a_autocomplete `Off] ()] ;
+  
+  "input autocomplete tokenlist",
+  [[%html "<input autocomplete='section-blue shipping street-address'/>"]],
+  [input ~a:[a_autocomplete (`Tokens ["section-blue"; "shipping"; "street-address"] )] ()] ;
+  
+  "input autocomplete tokenlist empty",
+  [[%html "<input autocomplete='on'/>"]],
+  [input ~a:[a_autocomplete (`Tokens [] )] ()] ;
 
   "link rel=canonical",
   [[%html "<link rel=canonical href='/'>"]],
@@ -271,6 +319,12 @@ let attribs = "ppx attribs", HtmlTests.make Html.[
   [[%html "<div data-foo='valfoo'></div>"]],
   [div
     ~a:[a_user_data "foo" "valfoo"] []] ;
+  
+  "arbitrary (unchecked) attributes via an escape hatch",
+  [[%html "<div _some-attr='value'></div>"]],
+  [div
+    ~a:[Unsafe.string_attrib "some-attr" "value"] []]
+      
 ]
 
 let ns_nesting = "namespace nesting" , HtmlTests.make Html.[
@@ -358,9 +412,17 @@ let svg = "svg", SvgTests.make Svg.[
   [[%svg "<feMorphology operator='erode'/>"]],
   [feMorphology ~a:[a_feMorphology_operator `Erode] []] ;
 
-  "animation fill, values",
-  [[%svg "<animation fill='freeze' values='1 2'/>"]],
-  [animation ~a:[a_animation_fill `Freeze; a_animation_values ["1"; "2"]] []] ;
+  "animate fill, values",
+  [[%svg "<animate fill='freeze' values='1 2'/>"]],
+  [animate ~a:[a_animation_fill `Freeze; a_animation_values ["1"; "2"]] []] ;
+
+  "fill_rule type nonzero",
+  [[%svg "<path fill-rule='nonzero'/>"]],
+  [path ~a:[a_fill_rule `Nonzero] []] ;
+
+  "fill_rule type evenodd",
+  [[%svg "<path fill-rule='evenodd'/>"]],
+  [path ~a:[a_fill_rule `Evenodd] []] ;
 
 ]
 
